html {
    font-size: 14px;
}

body {
    position: relative;
    background-color: #e0e0e0;
}

a:hover {
    cursor: pointer;
}

/* page header */
#mara-page-header {
    width: 100%;
    display: flex;
    flex-direction: row;
    flex-wrap: nowrap;
    flex-shrink: 0;
    height: 60px;
    max-height: 60px;
    border-bottom: 1px solid #ddd;
    background-color: #ffffff;
    padding: 0px;
    padding-left: 15px;
    padding-right: 15px;
}

#mara-page-header > * {
    align-self: center;
    margin: 0px;
}

#mara-page-header > div.action-buttons, #mara-page-header > h1 {
    overflow: hidden;
    white-space: nowrap;
    text-overflow: ellipsis;
}

@media (max-width: 600px) {
    #mara-page-header > img {
        display: none;
    }
}

#mara-page-header > img {
    height: 40px;
    margin-right: 10px;
}

#mara-page-header > h1 {
    font-size: 20px;
    font-weight: normal;
}

#mara-page-header > .action-buttons {
    flex-grow: 1;
    text-align: right;
    margin-left: 20px;
}

#mara-page-header > .action-buttons > a.btn {
    padding: 0px;
    margin-left: 20px;
}

#mara-page-header > .navigation-toggle-button {
    display: none;
    padding-right: 10px;
    text-decoration: none;
}

body.touch > #mara-page-header > .navigation-toggle-button {
    display: block;
}

/*
make sure that anchor links are not hidden behind the header
https://css-tricks.com/hash-tag-links-padding/
*/
.anchor {
    margin-top: -90px;
    padding-top: 90px;
    z-index: -1;
    display: inline-block;
}

/* navigation */
#mara-navigation {
    position: fixed;
    z-index: 1000;
    left: 0;
    top: 60px;
    bottom: 0;
    width: 224px;
    background-color: #333;
    color: #888;
    transition: width .3s;
    overflow-x: hidden;
    overflow-y: auto;
    display: block;
}

body.touch > #mara-navigation {
    transition: width 0s;
}

body.navigation-collapsed > #mara-navigation {
    width: 54px;
    transition: width .3s;
}

body.touch.navigation-collapsed > #mara-navigation {
    width: 0px;
    transition: width 0s;
}

/*
 nav entry
*/
#mara-navigation div.mara-nav-entry {
    width: 224px;
}

#mara-navigation div.highlighted > a {
    color: #fff !important;
    font-weight: bold;
}

#mara-navigation div.mara-nav-entry:not(.level-1) {
    background-color: #444;
}

#mara-navigation div.mara-nav-entry:hover {
    background-color: #171717;
}

#mara-navigation div.mara-nav-entry.level-1:not(:first-child) {
    border-top: 1px solid #2d2d2d;
}

#mara-navigation div.mara-nav-entry.level-1 > a {
    padding-left: 0px;
    padding-top: 12px;
    padding-bottom: 12px;
}

#mara-navigation div.mara-nav-entry.level-2 > a {
    padding-left: 30px;
}

#mara-navigation div.mara-nav-entry.level-3 > a {
    padding-left: 45px;
}

#mara-navigation div.mara-nav-entry.level-4 > a {
    padding-left: 60px;
}

#mara-navigation div.mara-nav-entry.level-5 > a {
    padding-left: 75px;
}

#mara-navigation div.mara-nav-entry > a {
    padding-top: 5px;
    padding-bottom: 5px;
    padding-right: 16px;
    display: table;
    width: 100%;
    color: #aaa;
    text-decoration: none;
    cursor: pointer;
}

#mara-navigation div.mara-nav-entry > a > div {
    display: table-cell;
}

#mara-navigation div.mara-nav-entry.level-1 > a > div.mara-nav-entry-icon {
    min-width: 54px;
    font-size: 20px;
    text-align: center;
}

#mara-navigation div.mara-nav-entry:not(.level-1) > a > div.mara-nav-entry-icon {
    padding-right: 8px;
}

#mara-navigation .mara-nav-entry > a > div.mara-nav-entry-text {
    width: 100%;
}

#mara-navigation .mara-nav-entry > a > div.mara-caret {
    padding-left: 8px;
    opacity: 1;
    transition: opacity 0.3s;
    transition-delay: 0.2s;
}

body.navigation-collapsed > #mara-navigation div.mara-nav-entry .mara-caret {
    opacity: 0;
    transition: opacity 0s;
}

/*
* main area
*/

body > #mara-main {
    position: absolute;
    left: 170px; /* nav expanded 224 - nav collapsed 54 */
    transition: left .3s;
    top: 60px;
    width: 100%;
    padding-top: 15px;
    padding-left: 69px; /* nav collapsed + 15 */
}

body.navigation-collapsed > #mara-main, body.navigation-collapsed > #alerts {
    left: 0px;
    transition: left .3s;
}

body.touch > #mara-main, body.touch > #alerts {
    left: 224px;
    transition: left 0s;
    padding-left: 15px;
}

body.touch > #alerts {
    padding-left: 30px;
}

body.touch.navigation-collapsed > #mara-main, body.touch.navigation-collapsed > #alerts {
    left: 0px;
    transition: left 0s;
}

body > #mara-main div.container-fluid {
    padding: 0px;
}

body > #alerts {
    position: fixed;
    left: 170px; /* nav expanded 224 - nav collapsed 54 */
    transition: left .3s;
    width: 100%;
    bottom: 0px;
    padding-left: 84px; /* nav collapsed + 30 */
    padding-right: 30px;
    opacity: 0.95;
}

/*
* Cards
*/

#mara-main div.card {
    margin-bottom: 16px;
}

#mara-main div.card div.card-header {
    width: 100%;
    display: flex;
    background-color: white;
    border: none;
}

#mara-main div.card div.card-header > div {
    flex-grow: 1;
    align-self: center;
    margin: 0px;
}

#mara-main div.card div.card-header div.card-header-right {
    text-align: right;
    padding-left: 10px;
}

#mara-main div.card div.card-header.fixed-header-height > div {
    overflow: hidden;
    white-space: nowrap;
    text-overflow: ellipsis;
}

#mara-main div.card div.card-block > div.card-block-content {
    overflow-x: auto;
    overflow-y: hidden;
}

#mara-main div.card div.card-block > div.card-block-content > *:first-child {
    padding-top: 0px;
    margin-top: 0px;
}

#mara-main div.card div.card-block > div.card-block-content > *:last-child {
    padding-bottom: 0px;
    margin-bottom: 0px;
}

#mara-main div.card div.card-block {
    padding-top: 1rem;
    padding-bottom: 1rem;
}

#mara-main div.card div.card-section {
    border-top: 1px solid rgba(0, 0, 0, .1);
}

/*
* tables
*/

table.mara-table {
    width: 100%;
    border-collapse: collapse;
}

table.mara-table th {
    background-color: rgba(255, 255, 255, 0.9);
}

table.mara-table th, table.mara-table tbody > tr:first-child > td {
    border-top: none;
}

table.mara-table th:first-child, table.mara-table td:first-child {
    padding-left: 0;
}

table.mara-table th, table.mara-table td {
    padding-left: 15px;
}

table.mara-table th:last-child, table.mara-table td:last-child {
    padding-right: 0px;
}

table.mara-table td pre, table.mara-table code {
    margin-top: 5px;
    margin-bottom: 5px;
}


/*
* Buttons
*/

a.mara-button {
    padding: 0px;
}

a.mara-button:focus, a.mara-button:active {
    box-shadow: none !important;
}

/*
* Misc
*/

#mara-main code {
    background-color: transparent;
    padding: 0px;
    border-radius: 0px;
    color: black;
}